SyncedOscs

Struct SyncedOscs 

pub struct SyncedOscs<T: DspFormat> { /* private fields */ }
A synced pair of Oscs. The secondary oscillator will be synced to the primary oscillator.

This implements Device, taking a Note as input and a SyncedOscsParams as parameters. It outputs a SyncedOscsOutput, which contains the output signals from both underlying oscillators.

Implementations

Source

impl<T: DspFormat> SyncedOscs<T>

pub fn new() -> Self

Constructor